# from https://prpm.dbp.gov.my/cari1?keyword=
# dbp https://en.wikipedia.org/wiki/Dewan_Bahasa_dan_Pustaka
MS_BASE_EXCEPTIONS = set(
    """
aba-aba
abah-abah
abar-abar
abrit-abritan
abu-abu
abuk-abuk
abun-abun
acak-acak
acak-acakan
acang-acang
aci-aci
aci-acian
aci-acinya
adang-adang
adap-adapan
adik-beradik
aduk-adukan
agak-agak
agar-agar
agut-agut
air-cooled
ajar-ajar
aji-aji
akal-akal
akhir-akhir
aki-aki
alah-mengalahi
alan-alan
alang-alang
alang-alangan
alap-alap
ali-ali
alih-alih
aling-aling
aling-alingan
alip-alipan
alon-alon
alu-alu
alu-aluan
alun-alun
alur-alur
ambah-ambah
ambai-ambai
ambil-mengambil
ambring-ambringan
ambu-ambu
ambung-ambung
amin-amin
ampai-ampai
amung-amung
anai-anai
anak-anak
anak-anakan
anak-beranak
ancak-ancak
ancang-ancang
andang-andang
angan-angan
anggar-anggar
angin-angin
angin-anginan
angkul-angkul
angkup-angkup
angkut-angkut
ani-ani
aning-aning
anjang-anjang
anjing-anjing
anjung-anjung
anjung-anjungan
antar-antar
ante-mortem
anting-anting
antung-antung
anyam-menganyam
apa-apa
api-api
apit-apit
aprit-apritan
arah-arah
arak-arakan
aram-aram
ari-ari
aru-aru
asa-asaan
asam-asaman
asuh-asuh
atas-mengatasi
ati-ati
audio-visual
avant-garde
awang-awang
awang-gemawang
ayak-ayak
ayam-ayam
ayam-ayaman
ayang-ayang
ayeng-ayengan
ayun-temayun
back-up
bahu-membahu
baik-baik
bajang-bajang
baji-baji
balai-balai
balam-balam
balas-membalas
baling-baling
balut-balut
bangun-bangun
bantal-bantal
barat-barat
barau-barau
bari-bari
barung-barung
basa-basi
bata-bata
batir-batir
bau-bauan
bayang-bayang
bedil-bedal
begana-begini
bekal-bekalan
belat-belit
belu-belai
benggal-benggil
bengkal-bengkil
bengkang-bengkok
bengkang-bengkong
berabad-abad
berabun-rabun
berada-ada
beragah-agah
beragak-agak
beragam-ragam
beraja-raja
berakit-rakit
beraku-akuan
beralun-alun
beramah-ramahan
beramah-tamah
beramai-ramai
berambai-ambai
berambal-ambalan
beramuk-amukan
berandai-andai
berandai-randai
berang-berang
berangan-angan
beranggap-anggapan
berangguk-angguk
berangin-angin
berangka-angka
berangka-angkaan
berangkai-rangkai
beranja-anja
berantai-rantai
berapi-api
berapung-apung
berarak-arakan
beras-beras
berasing-asingan
beratus-ratus
berawas-awas
berayal-ayalan
berayun-ayun
berbagai-bagai
berbahas-bahasan
berbalas-balasan
berbalik-balik
berbanjar-banjar
berbantah-bantah
berbanyak-banyak
berbarik-barik
berbasah-basah
berbatu-batu
berbayang-bayang
berbecak-becak
berbedil-bedilan
berbeka-beka
berbelakang-belakangan
berbelang-belang
berbeli-belian
berbelit-belit
berbelok-belok
berbenar-benar
berbencah-bencah
berbesar-besar
berbidai-bidai
berbiku-biku
berbilik-bilik
berbinar-binar
berbincang-bincang
berbingkah-bingkah
berbintang-bintang
berbintik-bintik
berbintil-bintil
berbisik-bisik
berbolak-balik
berbolong-bolong
berbondong-bondong
berbongkah-bongkah
berbuai-buai
berbual-bual
berbukit-bukit
berbulan-bulan
berbunga-bunga
berbuntut-buntut
berbunuh-bunuhan
berburu-buru
berburuk-buruk
berbutir-butir
bercabang-cabang
bercaci-cacian
bercakap-cakap
bercakar-cakaran
bercantik-cantik
bercari-cari
bercari-carian
bercarik-carik
bercepat-cepat
bercerai-berai
bercerai-cerai
bercetai-cetai
bercikun-cikun
bercinta-cintaan
bercita-cita
berciut-ciut
berconteng-conteng
bercoreng-coreng
bercoreng-moreng
bercuit-cuit
bercumbu-cumbu
bercumbu-cumbuan
bercura-bura
bercura-cura
berdada-dadaan
berdahulu-dahuluan
berdalam-dalam
berdebar-debar
berdecap-decap
berdedai-dedai
berdegap-degap
berdegar-degar
berdeham-deham
berdekah-dekah
berdekat-dekat
berdelat-delat
berdembun-dembun
berdempang-dempang
berdendam-dendaman
berdengkang-dengkang
berdentang-dentang
berdentum-dentum
berdentung-dentung
berdepak-depak
berdepan-depan
berderai-derai
berderak-derak
berderau-derau
berdering-dering
berderung-derung
berdesak-desakan
berdesing-desing
berdesus-desus
berdikit-dikit
berdingkit-dingkit
berdua-dua
berduri-duri
berduru-duru
berduyun-duyun
berebut-rebut
berebut-rebutan
beregang-regang
berek-berek
berembut-rembut
berempat-empat
berenak-enak
berenteng-renteng
beresah-resah
berfoya-foya
bergagah-gagahan
bergagap-gagap
bergalur-galur
berganda-ganda
berganti-ganti
bergarah-garah
bergaruk-garuk
bergegas-gegas
bergelang-gelang
bergelap-gelap
bergelas-gelasan
bergeleng-geleng
bergemal-gemal
bergembut-gembut
bergerek-gerek
bergesa-gesa
bergilir-gilir
bergolek-golek
bergores-gores
bergotong-royong
bergugus-gugus
bergulung-gulung
bergulut-gulut
bergumpal-gumpal
bergunung-gunung
berhadap-hadapan
berhamun-hamun
berhandai-handai
berhanyut-hanyut
berhari-hari
berhati-hati
berhilau-hilau
berhujan-hujan
beria-ia
beria-ria
beriak-riak
beribu-ribu
berigi-rigi
bering-bering
beringat-ingat
beringgit-ringgit
berintik-rintik
beriring-iring
beriring-iringan
berjabir-jabir
berjaga-jaga
berjagung-jagung
berjalan-jalan
berjalar-jalar
berjalin-jalin
berjalur-jalur
berjam-jam
berjauh-jauhan
berjejal-jejal
berjela-jela
berjenis-jenis
berjenjang-jenjang
berjilid-jilid
berjinak-jinak
berjingkat-jingkat
berjingkrak-jingkrak
berjongkok-jongkok
berjubel-jubel
berjujut-jujutan
berjulai-julai
berjumbai-jumbai
berjurai-jurai
berjurus-jurus
berjuta-juta
berkaca-kaca
berkait-kaitan
berkala-kala
berkali-kali
berkanjar-kanjar
berkaok-kaok
berkarung-karung
berkasih-kasihan
berkata-kata
berkatak-katak
berkecai-kecai
berkecek-kecek
berkecil-kecil
berkecil-kecilan
berkedip-kedip
berkejang-kejang
berkejap-kejap
berkejar-kejaran
berkelar-kelar
berkelip-kelip
berkelit-kelit
berkelok-kelok
berkelompok-kelompok
berkelun-kelun
berkembur-kembur
berkempul-kempul
berkena-kenaan
berkenal-kenalan
berkendur-kendur
berkeok-keok
berkepak-kepak
berkepal-kepal
berkeping-keping
berkepul-kepul
berkeras-kerasan
berkeritik-keritik
berkeruit-keruit
berkerut-kerut
berketak-ketak
berketak-ketik
berketi-keti
berketil-ketil
berketuk-ketak
berketul-ketul
berkial-kial
berkian-kian
berkias-kiasan
berkibar-kibar
berkilah-kilah
berkilat-kilat
berkilau-kilauan
berkilo-kilo
berkinja-kinja
berkipas-kipas
berkira-kira
berkirim-kiriman
berkobar-kobar
berkobok-kobok
berkocak-kocak
berkodi-kodi
berkolek-kolek
berkopah-kopah
berkotak-kotak
berkuat-kuatan
berkunang-kunang
berkurun-kurun
berkusau-kusau
berkusu-kusu
berkusut-kusut
berkuting-kuting
berkutu-kutuan
berlabun-labun
berlain-lainan
berlalai-lalai
berlama-lama
berlambai-lambai
berlambak-lambak
berlampang-lampang
berlapang-lapang
berlapis-lapis
berlapuk-lapuk
berlarah-larah
berlarat-larat
berlari-larian
berlarik-larik
berlarut-larut
berlawak-lawak
berlayap-layapan
berlebih-lebih
berlebih-lebihan
berlekas-lekas
berlena-lena
berlengah-lengah
berlenggek-lenggek
berlenggok-lenggok
berleret-leret
berliang-liuk
berliku-liku
berlimpah-limpah
berlimpap-limpap
berlimpit-limpit
berlinang-linang
berlindak-lindak
berlipat-lipat
berlompok-lompok
berloncat-loncatan
berlopak-lopak
berlubang-lubang
bermaaf-maafan
bermacam-macam
bermain-main
bermalas-malas
bermanik-manik
bermanis-manis
bermanja-manja
bermasak-masak
bermati-mati
bermegah-megah
bermemek-memek
bermesra-mesraan
bermewah-mewah
berminggu-minggu
berminta-minta
bermuda-muda
bermudah-mudah
bermuka-muka
bermula-mula
bermulut-mulut
bernafsi-nafsi
bernaka-naka
berniat-niat
berogak-ogak
beroleng-oleng
berolok-olok
beromong-omong
beronggok-onggok
berorang-orang
beroyal-royal
berpada-pada
berpahit-pahit
berpair-pair
berpal-pal
berpalu-palu
berpalu-paluan
berpalun-palun
berpandai-pandai
berpandang-pandangan
berpangkat-pangkat
berpanjang-panjang
berpasang-pasang
berpasang-pasangan
berpayah-payah
berpeluh-peluh
berpeluk-pelukan
berpenat-penat
berpencar-pencar
berpendar-pendar
berpenggal-penggal
berperai-perai
berpesai-pesai
berpesta-pesta
berpesuk-pesuk
berpetak-petak
berpeti-peti
berpihak-pihak
berpijar-pijar
berpikul-pikul
berpilih-pilih
berpilin-pilin
berpindah-pindah
berpintal-pintal
berpirau-pirau
berpisah-pisah
berpolah-polah
berpongah-pongah
berpontang-panting
berporah-porah
berpotong-potong
berpuak-puak
berpual-pual
berpugak-pugak
berpuluh-puluh
berpulun-pulun
berpuntal-puntal
berpura-pura
berpusar-pusar
berpusing-pusing
berpusu-pusu
berputar-putar
bersaf-saf
bersahut-sahutan
bersakit-sakit
bersalah-salahan
bersalam-salaman
bersalin-salin
bersama-sama
bersambut-sambutan
bersampan-sampan
bersantai-santai
bersapa-sapaan
bersarang-sarang
bersedan-sedan
bersedia-sedia
bersedu-sedu
bersekat-sekat
berselang-selang
berselang-seli
bersembur-semburan
bersempit-sempit
bersenang-senang
bersenang-senangkan
bersenda-senda
bersendi-sendi
bersepah-sepah
bersepi-sepi
berserak-serak
berseri-seri
bersesak-sesak
bersetai-setai
bersia-sia
bersiap-siap
bersiar-siar
bersilir-silir
bersimbur-simburan
bersinau-sinau
bersorak-sorai
bersuap-suapan
bersudah-sudah
bersuka-suka
bersuka-sukaan
bersuku-suku
bersumpah-sumpahan
bersungguh-sungguh
bersungut-sungut
bersunyi-sunyi
bersusah-susah
bersusuk-susuk
bersusuk-susukan
bersutan-sutan
bertabur-tabur
bertahu-tahu
bertahun-tahun
bertajuk-tajuk
bertakik-takik
bertala-tala
bertali-tali
bertalu-talu
bertambah-tambah
bertanda-tandaan
bertangis-tangisan
bertangkil-tangkil
bertanya-tanya
bertarik-tarikan
bertatai-tatai
bertatih-tatih
bertawan-tawan
bertawar-tawaran
bertebu-tebu
bertebu-tebukan
berteguh-teguh
berteguh-teguhan
berteka-teki
bertelau-telau
bertele-tele
bertempat-tempat
bertempuh-tempuh
bertenang-tenang
bertenggang-tenggangan
bertentu-tentu
bertepek-tepek
berterang-terang
berterang-terangan
bertikam-tikaman
bertimbal-timbalan
bertimbun-timbun
bertimpa-timpa
bertimpas-timpas
bertingkah-tingkah
bertingkat-tingkat
bertinjau-tinjauan
bertiras-tiras
bertitar-titar
bertoboh-toboh
bertolak-tolak
bertolak-tolakan
bertolong-tolongan
bertonjol-tonjol
bertua-tua
bertua-tuaan
bertual-tual
bertubi-tubi
bertukar-tukar
bertukar-tukaran
bertukas-tukas
bertumpak-tumpak
bertunda-tunda
bertunjuk-tunjukan
bertura-tura
berturut-turut
bertutur-tutur
beruas-ruas
berubah-ubah
berulang-alik
berulang-ulang
berumbai-rumbai
berundung-undung
berunggas-runggas
berungkur-ungkuran
beruntai-untai
beruntun-runtun
berunyai-unyai
berupa-rupa
berura-ura
beruris-uris
berurut-urutan
berwarna-warna
berwarna-warni
berwindu-windu
berwiru-wiru
beryang-yang
besar-besaran
betak-betak
beti-beti
betul-betul
biang-biang
biar-biar
biji-bijian
bila-bila
bilang-bilang
bincang-bincut
bini-binian
biri-biri
biru-biru
bisik-bisik
biti-biti
bolak-balik
bolang-baling
bongkar-bangkir
buah-buahan
buat-buatan
buaya-buaya
bubun-bubun
bugi-bugi
built-in
bukan-bukan
bulan-bulan
bulan-bulanan
bulang-bulang
bulat-bulat
buli-buli
bulu-bulu
buluh-buluh
bulus-bulus
bunga-bungaan
bunuh-membunuh
bunyi-bunyian
buru-buru
burung-burungan
bye-bye
cabik-cabik
caing-caing
calar-balar
cara-cara
carut-marut
cawi-cawi
cebar-cebur
celam-celum
celangak-celinguk
celas-celus
celedang-celedok
celengkak-celengkok
cemas-cemas
centang-perenang
cepat-cepat
cerai-berai
ceruk-menceruk
ceruk-meruk
check-up
chit-chat
cirit-birit
cita-cita
close-up
closed-circuit
cobak-cabik
cobar-cabir
cola-cala
compang-camping
congak-cangit
congkah-cangkih
congkah-mangkih
copak-capik
corak-carik
corat-coret
coreng-moreng
cuang-caing
cubung-cubung
culik-culik
cuma-cuma
cumi-cumi
cungap-cangip
cupu-cupu
dahulu-mendahului
dali-dali
dapur-dapur
dari-dari
daru-daru
datang-datang
datang-mendatangi
daun-daunan
dawai-dawai
dayang-dayang
degap-degap
dekak-dekak
dekat-dekat
dengar-dengaran
desas-desus
diam-diam
do-it-yourself
dokok-dokok
dolak-dalik
dorong-mendorong
drive-in
dua-dua
dua-duanya
duduk-duduk
dulang-dulang
ecek-ecek
embuh-embuhan
empek-empek
empok-empok
encal-encal
endap-endap
endut-endutan
engah-engah
enggan-enggan
engkah-engkah
entah-berentah
erang-erot
erong-erong
fast-food
fifty-fifty
flip-flop
follow-up
foya-foya
gaba-gaba
gabai-gabai
gada-gada
gading-gading
gado-gado
gajah-gajahan
gala-gala
gali-galian
galing-galing
galu-galu
gamit-gamitan
gampang-gampangan
ganal-ganal
ganda-berganda
gapah-gopoh
gara-gara
garah-garah
gatal-gatal
gawar-gawar
gaya-gayanya
gedebak-gedebuk
gelang-gelang
gelembung-gelembungan
geli-geli
geliang-geliut
geliat-geliut
gempul-gempul
gendang-gendang
genjang-genjot
gerabak-gerubuk
gerak-gerik
gerbas-gerbus
gerit-gerit
geruh-gerah
getak-getuk
geti-geti
gila-gila
gila-gilaan
gilang-gemilang
gilap-gemilap
gili-gili
giling-giling
ginang-ginang
girik-girik
giring-giring
go-kart
golak-galik
gonta-ganti
gotong-royong
gual-gail
gudu-gudu
gula-gula
gulang-gulang
guna-guna
guntang-guntang
gunung-ganang
gunung-gemunung
gunung-gunungan
habis-habis
habis-habisan
halai-balai
half-time
hampir-hampir
harap-harapan
harum-haruman
hati-hati
heavy-duty
hebat-hebatan
hidup-hidup
hiru-biru
hiruk-pikuk
hubaya-hubaya
hula-hula
huru-hara
ibar-ibar
icak-icak
igau-igauan
ikut-ikut
ikut-ikutan
ilam-ilam
imbang-imbangan
inang-inang
inca-binca
incang-incut
ingat-ingat
ingat-ingatan
ingau-ingauan
inggang-inggung
injak-injak
iras-iras
iring-iringan
iseng-iseng
jadi-jadian
jala-jala
jamah-jamahan
jambu-jambu
jangan-jangan
jarang-jarang
jari-jari
jaring-jaring
jarum-jarum
jauh-jauh
jawi-jawi
jebat-jebatan
jelur-jelir
jendal-jendul
jenggar-jenggur
jentik-jentik
jerah-jerih
jolong-jolong
jongkar-jangkir
juak-juak
juang-juang
julung-julung
jurai-jurai
kabu-kabu
kacang-kacang
kacang-kacangan
kacau-balau
kadang-kadang
kail-kail
kait-kait
kakek-kakek
kalau-kalau
kaleng-kalengan
kalut-malut
kambing-kambing
kanak-kanak
kapa-kapa
kapan-kapan
kapu-kapu
karang-karangan
karang-mengarang
kareseh-peseh
karut-marut
katang-katang
kawa-kawa
kayu-kayuan
keabu-abuan
keasyik-asyikan
kebarat-baratan
kebasah-basahan
kebat-kebit
kebata-bataan
kebelanda-belandaan
kebiru-biruan
kebudak-budakan
kecil-kecilan
kecil-mengecil
kecuh-kecah
kedek-kedek
kegadis-gadisan
kegelap-gelapan
kegila-gilaan
kegirang-girangan
kehijau-hijauan
kehitam-hitaman
kejaga-jagaan
kejingga-jinggaan
kekabur-kaburan
kekanak-kanakan
kekoboi-koboian
kekuning-kuningan
kelak-kelik
kelak-keluk
kelaki-lakian
kelang-kelok
kelap-kelip
kelek-kelek
kelek-kelekan
kelik-kelik
kelip-kelip
kelusuh-kelasah
kelut-melut
kemak-kemik
kemalu-maluan
kemanja-manjaan
kemarah-marahan
kemasam-masaman
kemati-matian
kemerah-merahan
kempang-kempis
kempas-kempis
kemuda-mudaan
kena-mengena
kenal-mengenal
kenang-kenangan
kencang-kencung
kendang-kendang
kendang-kendangan
kentung-kentung
kenyat-kenyit
kepandir-pandiran
kepang-kepot
keperak-perakan
kepilu-piluan
kepura-puraan
keputih-putihan
kerah-kerahan
kerancak-rancakan
kerang-kerangan
kerang-keroh
kerang-kerung
kerap-kerap
keras-mengerasi
kercap-kercip
kercap-kercup
keriang-keriut
kernyat-kernyut
kerong-kerong
keropas-kerapis
kertak-kertuk
keruntang-pungkang
kesap-kesip
kesenak-senakan
kesewenang-wenangan
kesia-siaan
kesik-kesik
kesipu-sipuan
kesu-kesi
kesuh-kesih
kesuk-kesik
ketergesa-gesaan
keti-keti
ketidur-tiduran
ketiga-tiganya
ketua-tuaan
ketuan-tuanan
keungu-unguan
kia-kia
kiak-kiak
kial-kial
kiang-kiut
kibang-kibut
kicang-kecoh
kicang-kicu
kida-kida
kilau-mengilau
kili-kili
kira-kira
kira-kiraan
kisi-kisi
kocah-kacih
kodok-kodok
kolang-kaling
koleh-koleh
kolong-kolong
koma-koma
komat-kamit
kontal-kantil
kontang-kanting
kosak-kasik
kotak-katik
kotak-kotak
kuat-kuat
kucar-kacir
kucing-kucing
kucing-kucingan
kuda-kuda
kuda-kudaan
kudap-kudap
kulah-kulah
kulak-kulak
kulik-kulik
kulum-kulum
kumat-kamit
kunang-kunang
kupat-kapit
kupu-kupu
kura-kura
kurang-kurang
kusat-mesat
kutat-kutet
kuti-kuti
labi-labi
labu-labu
lagi-lagi
laguh-lagah
laki-laki
lalu-lalang
lama-kelamaan
lama-lama
lamat-lamat
lambat-lambat
lancar-lancar
langak-longok
langit-langit
lanja-lanjaan
lapat-lapat
large-scale
lari-lari
lauk-pauk
lawah-lawah
lawak-lawak
lawi-lawi
layang-layang
layu-layuan
lebih-lebih
legak-legok
lekak-lekuk
lekap-lekup
lekas-lekas
lekuh-lekih
lekup-lekap
lenggak-lenggok
lenggok-lenggok
lengket-lengket
lentam-lentum
lentang-lentok
lentang-lentung
lepa-lepa
lerang-lerang
lereng-lereng
letah-letai
letup-letup
liang-liuk
lidah-lidah
line-up
liuk-liuk
liung-liung
lobi-lobi
lock-up
lopak-lapik
lopak-lopak
lumba-lumba
lumi-lumi
luntang-lantung
lupa-lupa
lupa-lupaan
main-mainan
makan-makanan
make-up
malai-malai
malam-malam
malar-malar
mali-mali
malu-malu
mana-mana
manik-manik
manis-manisan
mark-up
masing-masing
mata-mata
mati-matian
maya-maya
megap-megap
megrek-megrek
melak-melak
melambai-lambai
melambai-lambaikan
melambat-lambatkan
melaun-laun
melawak-lawak
melayap-layap
melayap-layapkan
melebih-lebihi
melebih-lebihkan
melejang-lejangkan
melengah-lengah
melihat-lihat
melimpah-limpah
melincah-lincah
meloncat-loncat
melonco-lonco
melonjak-lonjak
memacak-macak
memaki-maki
memaksa-maksa
memandai-mandai
memanggil-manggil
memanis-manis
memanjut-manjut
memasak-masak
memata-matai
mematah-matah
mematut-matut
memayah-mayahkan
membagi-bagikan
membalik-balik
membangkit-bangkit
membayang-bayangi
membayang-bayangkan
membelai-belai
membenar-benar
membenar-benari
memberai-beraikan
membesar-besarkan
membolak-balikkan
membuang-buang
membuat-buat
membunga-bungai
memburu-buru
memburu-burukan
memburuk-burukkan
memencak-mencak
memencar-mencar
memetak-metak
memetang-metangkan
memetir-metir
memikir-mikirkan
memilih-milih
meminang-minang
meminta-minta
memisah-misahkan
memontang-mantingkan
memperamat-amat
memperamat-amatkan
memperbagai-bagaikan
memperganda-gandakan
memperganduh-ganduhkan
mempermacam-macamkan
memperolok-olokkan
mempersama-samakan
mempertubi-tubi
mempertubi-tubikan
memperturut-turutkan
memuja-muja
memukang-mukang
memulun-mulun
memundi-mundi
memundi-mundikan
memuyu-muyu
menagak-nagak
menakut-nakuti
menanjur-nanjur
menanti-nanti
menari-nari
mencabik-cabik
mencabik-cabikkan
mencaing-caing
mencak-mencak
mencakup-cakup
mencapak-capak
mencari-cari
mencarik-carik
mencarut-carut
mencengis-cengis
mencepak-cepak
mencepuk-cepuk
mencerai-beraikan
mencetai-cetai
menciap-ciap
menciar-ciar
mencita-citakan
menciut-ciut
mencoang-coang
mencubit-cubit
mencuri-curi
mendecap-decap
mendengking-dengking
menderak-derakkan
menderau-derau
menderu-deru
mendesas-desuskan
mendesus-desus
mendewa-dewakan
mendudu-dudu
menebu-nebu
menegur-neguri
mengabung-ngabung
mengaci-acikan
mengada-ada
mengaduk-aduk
mengagak-agak
mengagak-agihkan
mengagut-agut
mengais-ngais
mengali-ali
mengalur-alur
mengamang-amang
mengamat-amati
mengambai-ambaikan
mengambang-ambang
mengancak-ancak
mengangan-angankan
mengangguk-angguk
mengangin-anginkan
mengangkat-angkat
mengap-mengap
mengapa-apai
mengapi-apikan
mengarah-arahi
mengata-ngatai
mengaum-aumkan
mengejan-ejan
mengelai-ngelai
mengelepik-ngelepik
mengelus-elus
mengembut-embut
mengenap-enapkan
mengenjak-enjak
mengepak-ngepak
mengepak-ngepakkan
menggaba-gabai
menggalur-galur
menggamak-gamak
menggapai-gapai
menggapai-gapaikan
menggelepar-gelepar
menggelepar-geleparkan
menggemak-gemak
menggerecak-gerecak
menggesa-gesakan
menggili-gili
menggorek-gorek
menggosok-gosok
mengguit-guit
menghalai-balaikan
menghinap-hinap
mengiang-ngiang
mengibas-ngibas
mengidam-idamkan
mengilah-ngilahkan
mengilai-ilai
mengilat-ngilatkan
mengilik-ngilik
mengimak-imak
mengiming-iming
menginjak-injak
mengipas-ngipas
mengira-ngira
mengira-ngirakan
mengiras-iras
mengiras-irasi
mengitar-ngitar
mengitik-ngitik
mengogok-ogok
mengolak-alikkan
mengoleng-oleng
mengongkang-ongkang
mengongkok-ongkok
mengonyah-anyih
mengotak-ngatikkan
mengoyak-ngoyakkan
mengoyak-oyak
menguar-nguarkan
menguar-uarkan
menguber-uber
mengubit-ubit
mengubrak-abrik
mengucar-ngacirkan
mengucek-ngucek
menguik-uik
menguis-uis
mengulit-ulit
menguman-uman
mengumbang-ambingkan
mengumpak-umpak
mengungkat-ungkat
mengungkit-ungkit
mengurik-urik
mengutak-ngatikkan
mengutik-ngutik
menimang-nimang
meningkat-ningkat
meniru-niru
meniup-niup
menjadi-jadi
menjengek-jengek
menjengit-jengit
menjilat-jilat
mentah-mentah
mentang-mentang
menunda-nunda
menusuk-nusuk
menyama-nyama
menyambar-nyambar
menyanjung-nyanjung
menyapu-nyapu
menyarat-nyarat
menyendi-nyendi
menyeret-nyeret
menyeru-nyerukan
menyia-nyiakan
menyungguh-nyungguhi
meraba-raba
merangkak-rangkak
merasa-rasai
meraung-raung
meraung-raungkan
merayau-rayau
merayu-rayu
mereka-reka
merelap-relap
meremah-remah
meremeh-temehkan
merempah-rempahi
merengek-rengek
merenik-renik
merenta-renta
merenyai-renyai
merintang-rintang
merintik-rintik
merobek-robek
meronta-ronta
merungus-rungus
merungut-rungut
mewarna-warnikan
meyakin-yakini
miju-miju
minta-minta
moga-moga
morat-marit
muda-mudi
mudah-mudahan
muka-muka
mula-mula
muluk-muluk
naga-naga
nanti-nantian
nasi-nasi
nasib-nasiban
nenek-nenek
nyolong-nyolong
ogah-ogahan
ogak-ogak
olak-alik
olak-olak
olang-aling
olang-alingan
oleh-oleh
olok-olok
olok-olokan
olong-olong
on-screen
onde-onde
one-to-one
oneng-oneng
ongkang-ongkang
ongol-ongol
onyah-anyih
orak-arik
orang-aring
orang-orangan
orok-orok
orong-orong
otak-otak
otak-otakan
padi-padian
pagi-pagi
palas-palas
paling-paling
palu-memalu
panas-panas
pandang-memandang
panji-panji
para-para
paru-paru
pasang-memasang
pasu-pasu
paya-paya
pecah-pecah
pelan-pelan
pengundang-undang
perang-perangan
perintang-rintang
perlahan-lahan
perlip-perlipan
pertama-tama
perundang-undangan
pesan-pesan
piat-piut
pick-up
pijak-pijak
pijar-pijar
pijat-pijat
pina-pina
pisang-pisang
play-off
pohon-pohonan
pokrol-pokrolan
polang-paling
poma-poma
pontang-panting
porak-parik
porak-peranda
potong-memotong
puji-pujian
pukang-pukang
pukul-memukul
pulang-pergi
pulut-pulut
pundi-pundi
punggung-memunggung
pura-pura
pusar-pusar
push-up
pusing-pusing
putus-putus
rada-rada
radio-frequency
ragu-ragu
rama-rama
rambu-rambu
rango-rango
rasa-rasanya
rata-rata
real-time
rebah-rebah
rebah-rebahan
redam-redam
reka-reka
reka-rekaan
remah-remah
remang-remang
rembah-rembih
remeh-temeh
rempah-rempah
repuh-repuh
riang-riang
ribu-ribu
rigi-rigi
robak-rabik
robat-rabit
role-play
roll-on
rombang-rambing
ruak-ruak
ruku-ruku
rumah-rumah
rumah-rumahan
rumput-rumputan
runding-merunding
runggu-rangga
runner-up
rupa-rupa
rupa-rupanya
saban-saban
sabung-menyabung
saing-menyaing
salah-salah
sama-sama
samar-samar
sambar-menyambar
sambung-bersambung
sambung-menyambung
sambut-menyambut
sampai-sampai
sandar-menyandar
sangat-sangat
sangkut-menyangkut
sapa-menyapa
sapu-sapu
sarit-sarit
satu-satu
satu-satunya
sayup-menyayup
sayup-sayup
sayur-mayur
sayur-sayuran
sci-fi
seakal-akal
seakan-akan
sealak-alak
sebaik-baiknya
sebelah-menyebelah
sebentar-sebentar
seberang-menyeberang
seboleh-bolehnya
sedalam-dalamnya
sedang-menyedang
sedap-sedapan
sedapat-dapatnya
sedikit-dikitnya
sedikit-sedikit
sedikit-sedikitnya
seelok-eloknya
segala-galanya
segan-menyegan
segan-menyegani
segan-segan
sehari-hari
sehari-harian
sejadi-jadinya
sekali-kali
sekali-sekali
sekira-kira
sekonyong-konyong
sekuasa-kuasanya
sekurang-kurangnya
sela-menyela
sela-sela
selama-lamanya
selambat-lambatnya
selang-seli
selang-seling
selar-belar
selat-latnya
selekas-lekasnya
selepas-lepas
self-esteem
self-help
sema-sema
semah-semah
semak-semak
semalam-malaman
semasa-masa
semata-mata
sembunyi-sembunyi
sembunyi-sembunyian
semena-mena
semenda-menyemenda
semengga-mengga
sementang-mentang
semu-semu
semut-semutan
sengal-sengal
sengau-sengauan
seolah-olah
sepala-pala
sepandai-pandai
sepetang-petangan
sepoi-sepoi
sepuas-puasnya
serang-menyerang
seraya-menyeraya
serba-serbi
serbah-serbih
serembah-serembih
sering-sering
serta-menyertai
serta-serta
sesal-menyesali
sesudah-sudah
sesudah-sudahnya
sesuka-suka
setempat-setempat
setengah-setengah
setidak-tidaknya
seupaya-upaya
seupaya-upayanya
sewaktu-waktu
sewenang-wenang
short-term
sia-sia
siang-siang
siapa-siapa
sibar-sibar
sibur-sibur
sida-sida
siku-siku
silah-silah
silang-menyilang
silir-semilir
sinar-seminar
sindir-menyindir
singgah-menyinggah
sorak-sorai
stand-by
stand-up
sudu-sudu
sudung-sudung
suka-suka
sulang-menyulang
sulur-suluran
sumpah-sumpah
sumpit-sumpit
sungguh-sungguh
sungut-sungut
suram-suram
surat-menyurat
suruh-suruhan
tabar-tabar
tabir-mabir
tabrak-tubruk
tabuh-tabuhan
tahu-menahu
tahu-tahu
takang-takik
take-off
takut-takut
takut-takutan
tali-bertali
tali-tali
tampak-tampak
tanam-menanam
tanam-tanaman
tanda-tanda
tangan-menangan
tangan-tangan
tanggung-menanggung
tapa-tapa
tapak-tapak
tari-menari
tari-tarian
tarik-menarik
tatah-tatah
tawak-tawak
tawang-tawang
tawar-menawar
tawar-tawar
tayum-temayum
tebu-tebu
tegak-tegak
teka-teki
temas-temas
tembak-menembak
temut-temut
tenggang-menenggang
teraba-raba
terambang-ambang
terang-terang
terang-terangan
teranggar-anggar
terangguk-angguk
teranggul-anggul
terangin-angin
terangkup-angkup
teranja-anja
terapung-apung
terayan-rayan
terayap-rayap
terbada-bada
terbahak-bahak
terbata-bata
terbatuk-batuk
terbayang-bayang
terbengkil-bengkil
terbirit-birit
terbuai-buai
terbuang-buang
terburu-buru
tercangak-cangak
tercengang-cengang
tercilap-cilap
tercongget-congget
tercungap-cungap
terdangka-dangka
terdengih-dengih
terekeh-ekeh
terembut-embut
terembut-rembut
terengah-engah
teresak-esak
tergagap-gagap
tergagau-gagau
tergaguk-gaguk
tergapai-gapai
tergegap-gegap
tergegas-gegas
tergelung-gelung
tergerenyeng-gerenyeng
tergesa-gesa
tergila-gila
tergontai-gontai
tergudik-gudik
terguling-guling
tergulut-gulut
terharak-harak
terharap-harap
terhengit-hengit
terhinggut-hinggut
terigau-igau
terincut-incut
teringa-inga
teringat-ingat
terinjak-injak
terjembak-jembak
terjerit-jerit
terkadang-kadang
terkakah-kakah
terkakak-kakak
terkanjar-kanjar
terkapah-kapah
terkapai-kapai
terkapung-kapung
terkatah-katah
terkatung-katung
terkecap-kecap
terkedek-kedek
terkedip-kedip
terkejar-kejar
terkekau-kekau
terkekeh-kekeh
terkekek-kekek
terkelinjat-kelinjat
terkelip-kelip
terkempul-kempul
terkemut-kemut
terkencar-kencar
terkepak-kepak
terkesot-kesot
terkesut-kesut
terkial-kial
terkincak-kincak
terkindap-kindap
terkinja-kinja
terkirai-kirai
terkitar-kitar
terkocoh-kocoh
terkokol-kokol
terkosel-kosel
terkoteng-koteng
terkumpal-kumpal
terlara-lara
terlayang-layang
terlebih-lebih
terlincah-lincah
terliuk-liuk
terlolong-lolong
terlongong-longong
termangu-mangu
termanja-manja
termata-mata
termengah-mengah
termimpi-mimpi
ternanti-nanti
terngiang-ngiang
teroleng-oleng
terpandang-pandang
terpecah-pecah
terpekik-pekik
terpereh-pereh
terpikau-pikau
terpinga-pinga
terpingkal-pingkal
terpontang-panting
terpusing-pusing
terputus-putus
tersanga-sanga
tersaruk-saruk
tersedan-sedan
tersedih-sedih
tersedu-sedu
tersendat-sendat
tersendeng-sendeng
tersengal-sengal
tersengguk-sengguk
tersengut-sengut
tersera-sera
terserak-serak
tersetai-setai
tersia-sia
tersipu-sipu
tersoja-soja
tersungkuk-sungkuk
tertagak-tagak
tertahan-tahan
tertatih-tatih
tertegun-tegun
tertekan-tekan
terteleng-teleng
terumbang-ambing
terumbang-umbang
terungkap-ungkap
terus-menerus
terus-terusan
think-tank
tiap-tiap
tiba-tiba
tidak-tidak
tidur-tidur
tie-dye
tiga-tiganya
tikam-menikam
tilik-menilik
timah-timah
timang-timangan
timbang-menimbang
timu-timu
tindih-bertindih
tinjau-meninjau
tip-off
tiru-tiruan
tiup-tiup
tokak-takik
tokok-menokok
tolak-menolak
tolong-menolong
top-level
trade-in
tua-tua
tuan-tuan
tuang-tuang
tuban-tuban
tukang-menukang
tukar-menukar
tulang-tulangan
tuli-tuli
tulis-menulis
tumbuh-tumbuhan
tune-up
tunggang-tunggit
tupai-tupai
turun-temurun
turut-menurut
turut-turutan
two-tone
uar-uar
ubel-ubel
ubun-ubun
ubur-ubur
uci-uci
udap-udapan
ugal-ugalan
uir-uir
ujar-ujar
ukir-mengukir
ula-ula
ulak-ulak
ulang-alik
ulang-aling
ulang-ulang
ulap-ulap
ular-ular
ular-ularan
ulung-ulung
umang-umang
umbang-ambing
umbi-umbian
umbul-umbul
umbut-umbut
uncang-uncit
undak-undakan
undang-undang
unduk-unduk
undung-undung
undur-undur
unggat-unggit
ungkit-ungkit
unting-unting
untung-untung
untung-untungan
upside-down
ura-ura
uran-uran
urat-urat
uring-uringan
urup-urup
urup-urupan
urus-urus
user-user
user-useran
utar-utar
voice-over
walk-out
wangi-wangian
wanti-wanti
wara-wara
warna-warni
water-cooled
world-class
yang-yang
""".split()
)
